@@ -1,5 +1,6 @@
 import json
 import psycopg2
+import pandas as pd
 from .base import Connector
 
 
@@ -55,3 +56,11 @@ class PgConnector(Connector):
         rec = cur.fetchone()[0]
         cur.close()
         return rec
+
+    def query_to_df(self, query):
+        cur = self.client.cursor()
+        cur.execute(query)
+        rec = cur.fetchall()
+        cols = [desc[0] for desc in cur.description]
+        cur.close()
+        return pd.DataFrame.from_records(rec, columns=cols)
\ No newline at end of file
